﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Dispatch
{
    class Program
    {
        static void Main(string[] args)
        {
           //  Przykład wywołania metody dispatch, umożliwiającej wysłanie nowej przesyłki
            try
            {
                string sLogin = ""; // Login konta w Postivo.pl
                string sApiPass = ""; // Hasło dostępu do konta przez API
                string iMsgType = "1"; // Typ przesyłki (1-przesyłka listowa, 2-Fax)

                //DOKUMENTY

                //Obiekt zawierający zawartość pliku z dokumentami 
                Postivo.DocumentFile document = new Postivo.DocumentFile();

                byte[] docByte = File.ReadAllBytes("C:\\Nazwa_Pliku.pdf");
                string imgString = Convert.ToBase64String(docByte);

                document.file_name = "Nazwa_Pliku.pdf";
                document.file_stream = imgString;

                // Tablica zawierająca zawartość plików z dokumetnami, które powinny być umieszczone
                // w przesyłce (Mozna podac wiele plików jako kolejne elementy tablicy)
                Postivo.DocumentFile[] arDocFiles = new Postivo.DocumentFile[] { document };

                //ODBIORCY

                // Dane odbiorców podane bezpośrednio:
                Postivo.Recipient recipment_1 = new Postivo.Recipient();
                recipment_1.id = 0;
                recipment_1.source = "inline";
                recipment_1.recipient_name = "Jan Nowak";
                recipment_1.recipient_address_prefix = "ul.";
                recipment_1.recipient_address = "Przykładowa";
                recipment_1.recipient_home_number = "2";
                recipment_1.recipient_flat_number = "5";
                recipment_1.recipient_post_code = "00-999";
                recipment_1.recipient_city = "Warszawa";
                recipment_1.recipient_fax_number = "000000000";

                // Odbiorcy z grupy odbiorców
                Postivo.Recipient recipment_2 = new Postivo.Recipient();
                recipment_2.source = "group";
                recipment_2.id = 1;

                // Odbiorca z ksiązki adresowej
                Postivo.Recipient recipment_3 = new Postivo.Recipient();
                recipment_3.source = "book";
                recipment_3.id = 1;

                // Tablica zawierająca dane odbiorców przesyłek
                Postivo.Recipient[] arRecipients = new Postivo.Recipient[] { recipment_1, recipment_2, recipment_3 };

                //PARAMETRY PRZESYŁKI

                // ID nadawcy przesyłki
                Postivo.Option option_1 = new Postivo.Option();
                option_1.name = "sender_id";
                option_1.value = "19";

                // ID profilu użytej konfiguracji
                Postivo.Option option_2 = new Postivo.Option();
                option_2.name = "config_id";
                option_2.value = "30";

                // data (w przypadku faksów również godzina i minuta) nadania przesyłki
                Postivo.Option option_3 = new Postivo.Option();
                option_3.name = "dispatch_date";
                option_3.value = "2011-01-21";

                // Tablica zawierająca parametry przesyłki
                Postivo.Option[] arDispatchOptions = new Postivo.Option[] { option_1, option_2, option_3 };

                // Utworzenie obiektu serwisu:
                Postivo.PostivoplPortTypeClient serwis = new Postivo.PostivoplPortTypeClient();

                // Wywołanie metody dispatch z przekazaniem wszystkich parametrów
                Postivo.DispatchReturnObject output = serwis.dispatch(sLogin, sApiPass, iMsgType, arDocFiles, arRecipients, arDispatchOptions);

                //DANE WYJŚCIOWE

                // Przykład obsługi danych wyjściowych:
                Console.WriteLine("Status żądania: " + output.result);
                Console.WriteLine("Kod statusu żądania: " + output.result_code);
                Console.WriteLine("Opis statusu żądania: " + output.result_description);

                foreach (Postivo.Shipment shipment in output.shipments)
                {

                    Console.WriteLine("Id przesyłki: " + shipment.id);
                    Console.WriteLine("Przesyłka dla: " + shipment.recipient_name + ", " + shipment.recipient_address + " " + shipment.recipient_home_number + " " + shipment.recipient_flat_number + ", " + shipment.recipient_post_code + " " + shipment.recipient_city + ", fax: " + shipment.recipient_fax_number);
                    Console.WriteLine("składająca się z: " + shipment.page_number + " stron ma status " + shipment.status + "(kod statusu: " + shipment.status_code + " opis kodu: " + shipment.status_description);

                    if (shipment.status.Equals("OK"))
                    {
                        Console.WriteLine("Zostanie nadana za pośrednictwem: " + shipment.dispatch_carrier + " jako: " + shipment.dispatch_type + ". Jej koszt to " + shipment.price + "zł netto");
                    }
                }
            }
            catch (Exception exeption)
            {
                Console.WriteLine("Wystąpił błąd: " + exeption.Message);
            }

        }
    }
}
